@@ -990,8 +990,10 @@ class FormatBtrfsCompressed(FormatBtrfs):
             if self.purpose != "boot" and self.compression:
                 Btrfs(self.dev).compression = self.compression
             if self.purpose == "root":
-                # disable btrfs compression for /boot directory in partition
+                # disable btrfs compression for /boot directory in root partition
+                # and usr/share/grub for unicode.pf2
                 Btrfs(self.dev).set_compression("boot", "")
+                Btrfs(self.dev).set_compression("usr/share/grub", "")
         except BtrfsError as e:
             raise DistributiveError(
                 _("Failed to set btrfs compression for {}").format(self.dev))
