@@ -2336,6 +2336,10 @@ class VariableOsInstallFstabMountConf(DeviceHelper, ReadonlyVariable):
             return s
 
     def formatFstab(self, used, dev, mp, fs, opts, spec):
+        if fs in FileSystemManager.supportFS:
+            fs_orig = FileSystemManager.supportFS[fs].get('orig', fs)
+        else:
+            fs_orig = fs
         ret = "{dev}\t{mp}\t{fs}\t{opts}\t{spec}".format(
             dev=used, mp=mp, fs=fs, opts=opts, spec=spec
         )
